<?xml version="1.0" encoding="UTF-8"?>
<!--
Template derived pattern
===========================================
ID: 1.2.276.0.76.10.4074
Name: Problem Concern Act
Description: This template reflects an ongoing concern on behalf of the provider that placed the concern on a patient’s problem list. So long as the underlying condition is of concern to the provider (i.e., as long as the condition, whether active or resolved, is of ongoing concern and interest to the provider), the statusCode is “active”. Only when the underlying condition is no longer of concern is the statusCode set to “completed”. The effectiveTime reflects the time that the underlying condition was felt to be a concern; it may or may not correspond to the effectiveTime of the condition (e.g., even five years later, the clinician may remain concerned about a prior heart attack). The statusCode of the Problem Concern Act is the definitive indication of the status of the concern, whereas the effectiveTime of the nested Problem Observation is the definitive indication of whether or not the underlying condition is resolved. The effectiveTime/low of the Problem Concern Act asserts when the concern b
-->
<pattern xmlns="http://purl.oclc.org/dsdl/schematron"
         id="template-1.2.276.0.76.10.4074-2015-12-06T000000">
   <title>Problem Concern Act</title>
   <!--
Template derived rules for ID: 1.2.276.0.76.10.4074
Context: *[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]
Item: (ProblemConcernAct)
-->

   <!--
Template derived rules for ID: 1.2.276.0.76.10.4074
Context: *[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]
Item: (ProblemConcernAct)
-->

   <rule context="*[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]"
         id="d127e5267-false-d106896e0">
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="string(@classCode)=('ACT')">(ProblemConcernAct): Der Wert von @classCode MUSS 'ACT' sein.</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="not(@classCode) or (string-length(@classCode)&gt;0 and not(matches(@classCode,'\s')))">(ProblemConcernAct): Attribute @classCode MUSS vom Datentyp 'cs' sein</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="string(@moodCode)=('EVN')">(ProblemConcernAct): Der Wert von @moodCode MUSS 'EVN' sein.</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="not(@moodCode) or (string-length(@moodCode)&gt;0 and not(matches(@moodCode,'\s')))">(ProblemConcernAct): Attribute @moodCode MUSS vom Datentyp 'cs' sein</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="count(hl7:templateId[@root='1.2.276.0.76.10.4074'])&gt;=1">(ProblemConcernAct): Element hl7:templateId[@root='1.2.276.0.76.10.4074'] ist mandatory [min 1x].</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="count(hl7:templateId[@root='1.2.276.0.76.10.4074'])&lt;=1">(ProblemConcernAct): Element hl7:templateId[@root='1.2.276.0.76.10.4074'] kommt zu häufig vor [max 1x].</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="count(hl7:id)&gt;=1">(ProblemConcernAct): Element hl7:id ist required [min 1x].</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="count(hl7:code[(@code='CONC' and @codeSystem='2.16.840.1.113883.5.6')][not(@nullFlavor)])&gt;=1">(ProblemConcernAct): Element hl7:code[(@code='CONC' and @codeSystem='2.16.840.1.113883.5.6')][not(@nullFlavor)] ist mandatory [min 1x].</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="count(hl7:code[(@code='CONC' and @codeSystem='2.16.840.1.113883.5.6')][not(@nullFlavor)])&lt;=1">(ProblemConcernAct): Element hl7:code[(@code='CONC' and @codeSystem='2.16.840.1.113883.5.6')][not(@nullFlavor)] kommt zu häufig vor [max 1x].</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="count(hl7:statusCode[not(@nullFlavor)])&gt;=1">(ProblemConcernAct): Element hl7:statusCode[not(@nullFlavor)] ist mandatory [min 1x].</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="count(hl7:statusCode[not(@nullFlavor)])&lt;=1">(ProblemConcernAct): Element hl7:statusCode[not(@nullFlavor)] kommt zu häufig vor [max 1x].</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="count(hl7:effectiveTime[not(@nullFlavor)])&gt;=1">(ProblemConcernAct): Element hl7:effectiveTime[not(@nullFlavor)] ist mandatory [min 1x].</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="count(hl7:effectiveTime[not(@nullFlavor)])&lt;=1">(ProblemConcernAct): Element hl7:effectiveTime[not(@nullFlavor)] kommt zu häufig vor [max 1x].</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="count(hl7:entryRelationship[hl7:observation[hl7:templateId[@root='1.2.276.0.76.10.4075']]])&gt;=1">(ProblemConcernAct): Element hl7:entryRelationship[hl7:observation[hl7:templateId[@root='1.2.276.0.76.10.4075']]] ist mandatory [min 1x].</assert>
   </rule>
   <!--
Template derived rules for ID: 1.2.276.0.76.10.4074
Context: *[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:templateId[@root='1.2.276.0.76.10.4074']
Item: (ProblemConcernAct)
-->

   <rule context="*[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:templateId[@root='1.2.276.0.76.10.4074']"
         id="d127e5273-false-d107246e0">
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="string(@root)=('1.2.276.0.76.10.4074')">(ProblemConcernAct): Der Wert von @root MUSS '1.2.276.0.76.10.4074' sein.</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="not(@root) or matches(@root,'^[0-2](\.(0|[1-9]\d*))*$') or matches(@root,'^[A-Fa-f\d]{8}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{4}-[A-Fa-f\d]{12}$') or matches(@root,'^[A-Za-z][A-Za-z\d\-]*$')">(ProblemConcernAct): Attribute @root MUSS vom Datentyp 'uid' sein</assert>
   </rule>
   <!--
Template derived rules for ID: 1.2.276.0.76.10.4074
Context: *[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:id
Item: (ProblemConcernAct)
-->

   <!--
Template derived rules for ID: 1.2.276.0.76.10.4074
Context: *[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:code[(@code='CONC' and @codeSystem='2.16.840.1.113883.5.6')][not(@nullFlavor)]
Item: (ProblemConcernAct)
-->

   <rule context="*[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:code[(@code='CONC' and @codeSystem='2.16.840.1.113883.5.6')][not(@nullFlavor)]"
         id="d127e5280-false-d107274e0">
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="@nullFlavor or (@code='CONC' and @codeSystem='2.16.840.1.113883.5.6')">(ProblemConcernAct): Der Elementinhalt MUSS einer von 'code 'CONC' codeSystem '2.16.840.1.113883.5.6'' sein.</assert>
   </rule>
   <!--
Template derived rules for ID: 1.2.276.0.76.10.4074
Context: *[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:statusCode[not(@nullFlavor)]
Item: (ProblemConcernAct)
-->

   <!--
Template derived rules for ID: 1.2.276.0.76.10.4074
Context: *[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:effectiveTime[not(@nullFlavor)]
Item: (ProblemConcernAct)
-->

   <rule context="*[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:effectiveTime[not(@nullFlavor)]"
         id="d127e5288-false-d107302e0">
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="count(hl7:low[not(@nullFlavor)])&gt;=1">(ProblemConcernAct): Element hl7:low[not(@nullFlavor)] ist mandatory [min 1x].</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="count(hl7:low[not(@nullFlavor)])&lt;=1">(ProblemConcernAct): Element hl7:low[not(@nullFlavor)] kommt zu häufig vor [max 1x].</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="count(hl7:high)&lt;=1">(ProblemConcernAct): Element hl7:high kommt zu häufig vor [max 1x].</assert>
   </rule>
   <!--
Template derived rules for ID: 1.2.276.0.76.10.4074
Context: *[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:effectiveTime[not(@nullFlavor)]/hl7:low[not(@nullFlavor)]
Item: (ProblemConcernAct)
-->

   <!--
Template derived rules for ID: 1.2.276.0.76.10.4074
Context: *[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:effectiveTime[not(@nullFlavor)]/hl7:high
Item: (ProblemConcernAct)
-->

   <!--
Template derived rules for ID: 1.2.276.0.76.10.4074
Context: *[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author
Item: (ProblemConcernAct)
-->

   <rule context="*[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author"
         id="d127e5295-false-d107358e0">
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="string(@typeCode)=('AUT') or not(@typeCode)">(ProblemConcernAct): Der Wert von @typeCode MUSS 'AUT' sein.</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="string(@contextControlCode)=('OP') or not(@contextControlCode)">(ProblemConcernAct): Der Wert von @contextControlCode MUSS 'OP' sein.</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="count(hl7:functionCode)&lt;=1">(ProblemConcernAct): Element hl7:functionCode kommt zu häufig vor [max 1x].</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="count(hl7:time)&gt;=1">(ProblemConcernAct): Element hl7:time ist required [min 1x].</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="count(hl7:time)&lt;=1">(ProblemConcernAct): Element hl7:time kommt zu häufig vor [max 1x].</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="count(hl7:assignedAuthor)&gt;=1">(ProblemConcernAct): Element hl7:assignedAuthor ist required [min 1x].</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="count(hl7:assignedAuthor)&lt;=1">(ProblemConcernAct): Element hl7:assignedAuthor kommt zu häufig vor [max 1x].</assert>
   </rule>
   <!--
Template derived rules for ID: 1.2.276.0.76.10.90025
Context: *[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:functionCode
Item: (AuthorBody)
-->

   <rule context="*[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:functionCode"
         id="d107369e33-false-d107415e0">
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90025-2014-12-21T000000.html"
              test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">(AuthorBody): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>}:<value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>"</assert>
      <extends rule="CE"/>
      <let name="theCode" value="@code"/>
      <let name="theCodeSystem" value="@codeSystem"/>
      <let name="theCodeSystemVersion" value="@codeSystemVersion"/>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90025-2014-12-21T000000.html"
              test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.1.11.10267-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])">(AuthorBody): Der Elementinhalt MUSS einer von '2.16.840.1.113883.1.11.10267 ParticipationFunction (DYNAMIC)' sein.</assert>
   </rule>
   <!--
Template derived rules for ID: 1.2.276.0.76.10.90025
Context: *[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:time
Item: (AuthorBody)
-->

   <rule context="*[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:time"
         id="d107369e38-false-d107440e0">
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90025-2014-12-21T000000.html"
              test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TS' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">(AuthorBody): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:TS" haben, gefunden "{<value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>}:<value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>"</assert>
      <extends rule="TS"/>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90025-2014-12-21T000000.html"
              test="not(*)">(AuthorBody): <value-of select="local-name()"/> with datatype TS, SHOULD NOT have child elements.</assert>
   </rule>
   <!--
Template derived rules for ID: 1.2.276.0.76.10.90025
Context: *[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:assignedAuthor
Item: (AuthorBody)
-->

   <rule context="*[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:assignedAuthor"
         id="d107369e40-false-d107457e0">
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90025-2014-12-21T000000.html"
              test="string(@classCode)=('ASSIGNED') or not(@classCode)">(AuthorBody): Der Wert von @classCode MUSS 'ASSIGNED' sein.</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90025-2014-12-21T000000.html"
              test="count(hl7:id)&gt;=1">(AuthorBody): Element hl7:id ist required [min 1x].</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90025-2014-12-21T000000.html"
              test="count(hl7:code)&lt;=1">(AuthorBody): Element hl7:code kommt zu häufig vor [max 1x].</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90025-2014-12-21T000000.html"
              test="count(hl7:assignedPerson)&lt;=1">(AuthorBody): Element hl7:assignedPerson kommt zu häufig vor [max 1x].</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90025-2014-12-21T000000.html"
              test="count(hl7:representedOrganization)&lt;=1">(AuthorBody): Element hl7:representedOrganization kommt zu häufig vor [max 1x].</assert>
   </rule>
   <!--
Template derived rules for ID: 1.2.276.0.76.10.90025
Context: *[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:assignedAuthor/hl7:id
Item: (AuthorBody)
-->

   <rule context="*[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:assignedAuthor/hl7:id"
         id="d107369e44-false-d107523e0">
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90025-2014-12-21T000000.html"
              test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">(AuthorBody): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>}:<value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>"</assert>
      <extends rule="II"/>
   </rule>
   <!--
Template derived rules for ID: 1.2.276.0.76.10.90025
Context: *[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:assignedAuthor/hl7:code
Item: (AuthorBody)
-->

   <rule context="*[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:assignedAuthor/hl7:code"
         id="d107369e46-false-d107537e0">
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90025-2014-12-21T000000.html"
              test="(local-name-from-QName(resolve-QName(@xsi:type,.))='CE' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">(AuthorBody): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:CE" haben, gefunden "{<value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>}:<value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>"</assert>
      <extends rule="CE"/>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90025-2014-12-21T000000.html"
              test="@nullFlavor or (@codeSystem='2.16.840.1.113883.5.111')">(AuthorBody): Der Elementinhalt MUSS einer von 'codeSystem '2.16.840.1.113883.5.111'' sein.</assert>
   </rule>
   <!--
Template derived rules for ID: 1.2.276.0.76.10.90025
Context: *[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:assignedAuthor/hl7:addr
Item: (AuthorBody)
-->

   <rule context="*[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:assignedAuthor/hl7:addr"
         id="d107369e51-false-d107557e0">
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90025-2014-12-21T000000.html"
              test="(local-name-from-QName(resolve-QName(@xsi:type,.))='AD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">(AuthorBody): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:AD" haben, gefunden "{<value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>}:<value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>"</assert>
      <extends rule="AD"/>
   </rule>
   <!--
Template derived rules for ID: 1.2.276.0.76.10.90025
Context: *[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:assignedAuthor/hl7:telecom
Item: (AuthorBody)
-->

   <rule context="*[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:assignedAuthor/hl7:telecom"
         id="d107369e53-false-d107571e0">
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90025-2014-12-21T000000.html"
              test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TEL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">(AuthorBody): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:TEL" haben, gefunden "{<value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>}:<value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>"</assert>
      <extends rule="TEL"/>
   </rule>
   <!--
Template derived rules for ID: 1.2.276.0.76.10.90025
Context: *[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:assignedAuthor/hl7:assignedPerson
Item: (AuthorBody)
-->

   <rule context="*[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:assignedAuthor/hl7:assignedPerson"
         id="d107369e56-false-d107587e0">
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90025-2014-12-21T000000.html"
              test="string(@classCode)=('PSN') or not(@classCode)">(AuthorBody): Der Wert von @classCode MUSS 'PSN' sein.</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90025-2014-12-21T000000.html"
              test="string(@determinerCode)=('INSTANCE') or not(@determinerCode)">(AuthorBody): Der Wert von @determinerCode MUSS 'INSTANCE' sein.</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90025-2014-12-21T000000.html"
              test="count(hl7:name[not(@nullFlavor)])&gt;=1">(AuthorBody): Element hl7:name[not(@nullFlavor)] ist mandatory [min 1x].</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90025-2014-12-21T000000.html"
              test="count(hl7:name[not(@nullFlavor)])&lt;=1">(AuthorBody): Element hl7:name[not(@nullFlavor)] kommt zu häufig vor [max 1x].</assert>
   </rule>
   <!--
Template derived rules for ID: 1.2.276.0.76.10.90010
Context: *[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:assignedAuthor/hl7:assignedPerson/hl7:name[not(@nullFlavor)]
Item: (PersonElements)
-->

   <rule context="*[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:assignedAuthor/hl7:assignedPerson/hl7:name[not(@nullFlavor)]"
         id="d107598e22-false-d107625e0">
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90010-2011-12-19T000000.html"
              test="(local-name-from-QName(resolve-QName(@xsi:type,.))='PN' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">(PersonElements): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:PN" haben, gefunden "{<value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>}:<value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>"</assert>
      <extends rule="PN"/>
   </rule>
   <!--
Template derived rules for ID: 1.2.276.0.76.10.90025
Context: *[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:assignedAuthor/hl7:representedOrganization
Item: (AuthorBody)
-->

   <rule context="*[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:assignedAuthor/hl7:representedOrganization"
         id="d107369e61-false-d107641e0">
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90025-2014-12-21T000000.html"
              test="string(@classCode)=('ORG') or not(@classCode)">(AuthorBody): Der Wert von @classCode MUSS 'ORG' sein.</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90025-2014-12-21T000000.html"
              test="string(@determinerCode)=('INSTANCE') or not(@determinerCode)">(AuthorBody): Der Wert von @determinerCode MUSS 'INSTANCE' sein.</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90025-2014-12-21T000000.html"
              test="count(hl7:name[not(@nullFlavor)])&gt;=1">(AuthorBody): Element hl7:name[not(@nullFlavor)] ist mandatory [min 1x].</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90025-2014-12-21T000000.html"
              test="count(hl7:name[not(@nullFlavor)])&lt;=1">(AuthorBody): Element hl7:name[not(@nullFlavor)] kommt zu häufig vor [max 1x].</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90025-2014-12-21T000000.html"
              test="count(hl7:addr)&lt;=1">(AuthorBody): Element hl7:addr kommt zu häufig vor [max 1x].</assert>
   </rule>
   <!--
Template derived rules for ID: 1.2.276.0.76.10.90011
Context: *[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:assignedAuthor/hl7:representedOrganization/hl7:id
Item: (OrganizationElements)
-->

   <rule context="*[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:assignedAuthor/hl7:representedOrganization/hl7:id"
         id="d107652e24-false-d107697e0">
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90011-2011-12-19T000000.html"
              test="(local-name-from-QName(resolve-QName(@xsi:type,.))='II' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">(OrganizationElements): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:II" haben, gefunden "{<value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>}:<value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>"</assert>
      <extends rule="II"/>
   </rule>
   <!--
Template derived rules for ID: 1.2.276.0.76.10.90011
Context: *[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:assignedAuthor/hl7:representedOrganization/hl7:name[not(@nullFlavor)]
Item: (OrganizationElements)
-->

   <rule context="*[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:assignedAuthor/hl7:representedOrganization/hl7:name[not(@nullFlavor)]"
         id="d107652e29-false-d107711e0">
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90011-2011-12-19T000000.html"
              test="(local-name-from-QName(resolve-QName(@xsi:type,.))='ON' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">(OrganizationElements): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:ON" haben, gefunden "{<value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>}:<value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>"</assert>
      <extends rule="ON"/>
   </rule>
   <!--
Template derived rules for ID: 1.2.276.0.76.10.90011
Context: *[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:assignedAuthor/hl7:representedOrganization/hl7:telecom
Item: (OrganizationElements)
-->

   <rule context="*[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:assignedAuthor/hl7:representedOrganization/hl7:telecom"
         id="d107652e33-false-d107725e0">
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90011-2011-12-19T000000.html"
              test="(local-name-from-QName(resolve-QName(@xsi:type,.))='TEL' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">(OrganizationElements): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:TEL" haben, gefunden "{<value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>}:<value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>"</assert>
      <extends rule="TEL"/>
   </rule>
   <!--
Template derived rules for ID: 1.2.276.0.76.10.90011
Context: *[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:assignedAuthor/hl7:representedOrganization/hl7:addr
Item: (OrganizationElements)
-->

   <rule context="*[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:author/hl7:assignedAuthor/hl7:representedOrganization/hl7:addr"
         id="d107652e37-false-d107739e0">
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.90011-2011-12-19T000000.html"
              test="(local-name-from-QName(resolve-QName(@xsi:type,.))='AD' and namespace-uri-from-QName(resolve-QName(@xsi:type,.))='urn:hl7-org:v3') or not(@xsi:type)">(OrganizationElements): Wenn eine @xsi:type Instruktion anwesend ist MUSS diese den Wert "{urn:hl7-org:v3}:AD" haben, gefunden "{<value-of select="namespace-uri-from-QName(resolve-QName(@xsi:type,.))"/>}:<value-of select="local-name-from-QName(resolve-QName(@xsi:type,.))"/>"</assert>
      <extends rule="AD"/>
   </rule>

   <!--
Template derived rules for ID: 1.2.276.0.76.10.4074
Context: *[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:entryRelationship[hl7:observation[hl7:templateId[@root='1.2.276.0.76.10.4075']]]
Item: (ProblemConcernAct)
-->
   <rule context="*[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:entryRelationship[hl7:observation[hl7:templateId[@root='1.2.276.0.76.10.4075']]]">
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="string(@typeCode)=('SUBJ')">(ProblemConcernAct): Der Wert von @typeCode MUSS 'SUBJ' sein.</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="not(@typeCode) or (string-length(@typeCode)&gt;0 and not(matches(@typeCode,'\s')))">(ProblemConcernAct): Attribute @typeCode MUSS vom Datentyp 'cs' sein</assert>
   </rule>

   <!--
Template derived rules for ID: 1.2.276.0.76.10.4074
Context: *[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:entryRelationship[hl7:observation[hl7:templateId[@root='1.2.276.0.76.10.4076']]]
Item: (ProblemConcernAct)
-->
   <rule context="*[hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]]/hl7:act[hl7:templateId[@root='1.2.276.0.76.10.4074']]/hl7:entryRelationship[hl7:observation[hl7:templateId[@root='1.2.276.0.76.10.4076']]]">
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="string(@typeCode)=('REFR')">(ProblemConcernAct): Der Wert von @typeCode MUSS 'REFR' sein.</assert>
      <assert role="error"
              see="http://hl7de.art-decor.org/evthm-html-20170803T142932/tmp-1.2.276.0.76.10.4074-2015-12-06T000000.html"
              test="not(@typeCode) or (string-length(@typeCode)&gt;0 and not(matches(@typeCode,'\s')))">(ProblemConcernAct): Attribute @typeCode MUSS vom Datentyp 'cs' sein</assert>
   </rule>
</pattern>
